# aiopywttr

[![CI](https://github.com/monosans/aiopywttr/actions/workflows/ci.yml/badge.svg)](https://github.com/monosans/aiopywttr/actions/workflows/ci.yml)
[![Downloads](https://static.pepy.tech/badge/aiopywttr)](https://pepy.tech/project/aiopywttr)

Asynchronous wrapper for [wttr.in](https://wttr.in) weather forecast API.

Synchronous version [here](https://github.com/monosans/pywttr).

## Installation

```bash
python -m pip install -U aiopywttr pywttr-models
```

## Documentation

<https://aiopywttr.readthedocs.io/>

## License

[MIT](https://github.com/monosans/aiopywttr/blob/main/LICENSE)
